'use strict';

var DashboardController = angular.module('DashboardController', [])

DashboardController.controller('DashboardCtrl', ['$scope', '$location', '$routeParams', '$filter', 'Cliente', 'Construcao', 'Compra', 'CacheApp', 'Dashboard',
    ($scope, $location, $routeParams, $filter, Cliente, Construcao, Compra, CacheApp, Dashboard) => {
        
        $scope.sessao = CacheApp.getSessao();

        $scope.listaConstrucoes = [];
        $scope.listaPagar = [];
        $scope.listaReceber = [];
        $scope.listaAtividades = [];
        $scope.listaOcorrencias = [];
        $scope.listaImagens = [];

        $scope.LoadPage = () => {
            CacheApp.delConstrucao();
            CacheApp.delMaterial();
            CacheApp.delNotaFiscal();
            $scope.getConstrucoes();
        };

        $scope.getResumoSituacaoObras = () => {
            var params = { 
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
            }
            Dashboard.getResumoSituacaoObras(params,
                (data) =>  {
                    $scope.ExecucaoAtrasada = data.Instance[0].ExecucaoAtrasada;
                    $scope.ExecucaoNoPrazo = data.Instance[0].ExecucaoNoPrazo;
                    $scope.Finalizada = data.Instance[0].Finalizada;
                    $scope.Orcamento = data.Instance[0].Orcamento;
                    $scope.Administrativo = data.Instance[0].Administrativo;
                    $scope.TotalObras = $scope.ExecucaoAtrasada + $scope.ExecucaoNoPrazo + $scope.Finalizada + $scope.Orcamento + $scope.Administrativo;
                }
            );
        };

        $scope.getResumoFinanceiroObras = () => {
            var params = { 
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
            }
            Dashboard.getResumoFinanceiroObras(params,
                (data) => {
                    $scope.Saldo = data.Instance[0].Saldo;
                    $scope.Debido = data.Instance[0].Custo;
                    $scope.Credito = data.Instance[0].Receita;
                }
            );
        };

        $scope.getResumoAPagarObras = () => {
            var params = { 
                Opcao: $scope.opcaoAPagar,
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
            }
            Dashboard.getResumoAPagarObras(params, 
                (data) => {
                    $scope.listaPagar = data.Instance;
                    $scope.TotalAPagar = 0;
                    $scope.listaPagar.forEach(l => {
                        $scope.TotalAPagar += l.Valor;
                    });
                }
            )
        };

        $scope.getResumoAReceberObras = () => {
            var params = { 
                Opcao: $scope.opcaoAReceber,
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
            }
            Dashboard.getResumoAReceberObras(params, 
                (data) => {
                    $scope.listaReceber = data.Instance;
                    $scope.TotalAReceber = 0;
                    $scope.listaReceber.forEach(l => {
                        $scope.TotalAReceber += l.Valor;
                    });
                }
            )
        };

        $scope.getResumoOcorrenciaObras = () => {
            var params = { 
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
            }
            Dashboard.getResumoOcorrenciaObras(params,
                (data) => {
                    $scope.listaOcorrencias = data.Instance;
                    for (var i in $scope.listaOcorrencias){
                        $scope.listaOcorrencias[i].Data = new Date($scope.listaOcorrencias[i].Data).toLocaleDateString('pt-BR');
                    }
                }
            )
        };

        $scope.getResumoImagemObras = () => {
            var params = { 
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
            }
            Dashboard.getResumoImagemObras(params,
                (data) => {
                    $scope.listaImagens = data.Instance;
                    for (var i in $scope.listaImagens){
                        $scope.listaImagens[i].Data = new Date($scope.listaImagens[i].Data).toLocaleDateString('pt-BR');                    
                    }
                }
            )
        };

        $scope.getResumoCreditoDebito = () => {
            var params = { 
                Opcao: $scope.opcaoFluxoCaixa,
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
            }
            Dashboard.getResumoCreditoDebito(params,
                (data) => {
                
                var lineDebito = {
                    label: 'Custo',
                    borderColor: 'rgba(220,0,0,0.9)',
                    backgroundColor: 'rgba(220,0,0,0.9)',
                    data: []
                }
                
                var lineCredito = {
                    label: 'Receita',
                    borderColor: 'rgba(38,49,67,0.9)',
                    backgroundColor: 'rgba(38,49,67,0.9)',
                    data: []
                }

                var lineSaldo = {
                    label: 'Saldo',
                    borderColor: 'rgba(250,162,0,1)',
                    backgroundColor: 'rgba(250,162,0,0.1)',
                    data: [],
                    type: 'line',
                    fill: false,
                    lineTension: 0
                }

                var plota = {
                    type: 'bar',
                    objName: 'bar-fluxocaixa',
                    showLegend: true,
                    showYAxes: true,
                    showXAxes: true,
                    stackedBar: true,
                    labels: [],
                    dataSet:[lineDebito, lineCredito, lineSaldo]
                };

                data.Instance.forEach(l => {
                    plota.labels.push(l.Periodo);
                    lineDebito.data.push(l.Debito);
                    lineCredito.data.push(l.Credito);
                    lineSaldo.data.push(l.Saldo);
                });

                $scope.plotaChart(plota);

            })
        };

        $scope.getConstrucoes = () => {
            $scope.AtualizaConstrucao();
            var tipo = $scope.almoxarifado ? 2 : ($scope.administrativo ? 3 : 1);
            var params = { 
                Tipo: tipo, 
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
            }
            Construcao.getListaObras(params,
                (data) => {

                    // for (var i in data.Instance)
                    //     if(data.Instance[i].Dono == true)
                    //         $scope.listaConstrucoes.push(data.Instance[i]);
                    $scope.listaConstrucoes = data.Instance;

                    $scope.almoxarifado = $location.path() ? ($location.path().indexOf('almoxarifados') > 0) : false;
                    $scope.administrativo = $location.path() ? ($location.path().indexOf('administrativo') > 0) : false;
                    $scope.titulo = 'Dashboard';

                    $scope.backupListaObras = [];
                    
                    for (var i in $scope.listaConstrucoes){
                        var construcao = $scope.listaConstrucoes[i];
                        var datanow = construcao.DataFinalizada ? new Date(construcao.DataFinalizada) : Date.now();
                        if (datanow < new Date($scope.listaConstrucoes[i].DataInicio)) {
                            $scope.listaConstrucoes[i].diasDecorridos = 0;
                            $scope.listaConstrucoes[i].dias = Math.ceil((Math.abs(new Date($scope.listaConstrucoes[i].DataInicio) - new Date($scope.listaConstrucoes[i].DataFim))) / (1000 * 3600 * 24));
                        }

                        else {
                            $scope.listaConstrucoes[i].diasDecorridos = Math.ceil((Math.abs(new Date($scope.listaConstrucoes[i].DataInicio) - datanow)) / (1000 * 3600 * 24)) - 1;
                            if (datanow < new Date($scope.listaConstrucoes[i].DataFim)) {
                                $scope.listaConstrucoes[i].dias = Math.ceil((Math.abs(datanow - new Date($scope.listaConstrucoes[i].DataFim))) / (1000 * 3600 * 24));
                                $scope.listaConstrucoes[i].atrasado = false;
                            }
                            else {
                                $scope.listaConstrucoes[i].dias = Math.ceil((Math.abs(new Date($scope.listaConstrucoes[i].DataFim) - datanow)) / (1000 * 3600 * 24)) - 1;
                                $scope.listaConstrucoes[i].atrasado = true;
                            }
                        }

                        $scope.backupListaObras.push($scope.listaConstrucoes[i]);
                    }
                    
                    $scope.opcaoFluxoCaixa = 8;
                    $scope.opcaoAPagar = 2;
                    $scope.opcaoAReceber = 3;

                    $scope.getResumoSituacaoObras();
                    $scope.getResumoFinanceiroObras();
                    $scope.getResumoAPagarObras();
                    $scope.getResumoAReceberObras();
                    $scope.getResumoOcorrenciaObras();
                    $scope.getResumoImagemObras();
                    $scope.getResumoCreditoDebito();
            });
        };

        $scope.filtraConstrucoes = (tipo) => {
            $scope.listaConstrucoes = [];
            $scope.listaConstrucoes = tipo == 'TotalObras' ? $scope.backupListaObras : $filter('filter')($scope.backupListaObras, {Situacao: tipo});
        }

        $scope.detalheConstrucao = (construcao) => {
            CacheApp.setConstrucao(construcao);
            $location.path("/dashboardobra");
        };

        $scope.detalharNota = (nota) => {

            var construcao = {};
            $scope.listaConstrucoes.forEach(c => {
                if(c.Id == nota.IdConstrucao)
                    construcao = c;
            });
            CacheApp.setConstrucao(construcao);
            Compra.getNotasFiscais(construcao.Id, nota.IdNotaFiscal,
                (data) => {
                    var notafiscal = data.Instance[0];
                    CacheApp.setNotaFiscal(notafiscal);
                    $location.path('/notafiscal/manter/' + (notafiscal.Natureza == 0 ? 'debito' : 'credito'));
            });

        };

        $scope.listaConstrucoesSelecionada = (tipo) => {
            $scope.sessao.TipoObra = tipo;
            CacheApp.setSessao($scope.sessao);
            $location.path("/");
        };
        
        $scope.AcessoAndroid($routeParams, (sim) => {
            $scope.AcessoMobile = sim;
            $scope.LoadPage();
        });

    }]
);